==> mx-packageinstaller-pkglist_19.04.04.tar.xz: mx-packageinstaller-pkglist/filezilla.pm <==
<?xml version="1.0"?>
<app>

<category>
FTP
</category>

<name>
Filezilla
</name>

<description>
   <am>a full-featured FTP client with an easy-to-use GUI</am>
   <ar>a full-featured FTP client with an easy-to-use GUI</ar>
   <bg>a full-featured FTP client with an easy-to-use GUI</bg>
   <ca>un client de FTP complet amb IGU fàcil d'usar</ca>
   <cs>a full-featured FTP client with an easy-to-use GUI</cs>
   <da>en FTP-klient med det hele med en brugerflade som er let at bruge</da>
   <de>Ein voll ausgestatter FTP-Client mit benutzerfreundliche Oberfläche</de>
   <el>ένα πλήρως εξοπλισμένο πρόγραμμα-πελάτη FTP με ένα εύχρηστο GUI</el>
   <en>a full-featured FTP client with an easy-to-use GUI</en>
   <es>un cliente FTP con una interfaz completa y fácil de usar</es>
   <et>a full-featured FTP client with an easy-to-use GUI</et>
   <eu>a full-featured FTP client with an easy-to-use GUI</eu>
   <fa>a full-featured FTP client with an easy-to-use GUI</fa>
   <fi>a full-featured FTP client with an easy-to-use GUI</fi>
   <fr>Un client FTP très complet avec une interface graphique intuitive</fr>
   <he_IL>a full-featured FTP client with an easy-to-use GUI</he_IL>
   <hi>a full-featured FTP client with an easy-to-use GUI</hi>
   <hr>a full-featured FTP client with an easy-to-use GUI</hr>
   <hu>a full-featured FTP client with an easy-to-use GUI</hu>
   <id>a full-featured FTP client with an easy-to-use GUI</id>
   <is>a full-featured FTP client with an easy-to-use GUI</is>
   <it>Client Ftp ad interfaccia grafica, completo e di facile uso</it>
   <ja_JP>a full-featured FTP client with an easy-to-use GUI</ja_JP>
   <ja>a full-featured FTP client with an easy-to-use GUI</ja>
   <kk>a full-featured FTP client with an easy-to-use GUI</kk>
   <ko>a full-featured FTP client with an easy-to-use GUI</ko>
   <lt>a full-featured FTP client with an easy-to-use GUI</lt>
   <mk>a full-featured FTP client with an easy-to-use GUI</mk>
   <nb>a full-featured FTP client with an easy-to-use GUI</nb>
   <nl>een volledig voorzien FTP programma met een makkelijk te gebruiken grafische werkomgeving</nl>
   <pl>w pełni funkcjonalny klient FTP z łatwym w użyciu interfejsem graficznym</pl>
   <pt_BR>a full-featured FTP client with an easy-to-use GUI</pt_BR>
   <pt>Cliente FTP completo com interface gráfica intuitiva</pt>
   <ro>a full-featured FTP client with an easy-to-use GUI</ro>
   <ru>Полнофункциональный FTP клиент с удобным GUI</ru>
   <sk>a full-featured FTP client with an easy-to-use GUI</sk>
   <sl>a full-featured FTP client with an easy-to-use GUI</sl>
   <sq>a full-featured FTP client with an easy-to-use GUI</sq>
   <sr>a full-featured FTP client with an easy-to-use GUI</sr>
   <sv>en fullutrustad FTP klient med lättanvänt grafiskt gränssnitt</sv>
   <tr>a full-featured FTP client with an easy-to-use GUI</tr>
   <uk>повнофункціональний FTP-клієнт з простим у використанні графічним інтерфейсом</uk>
   <zh_CN>a full-featured FTP client with an easy-to-use GUI</zh_CN>
   <zh_TW>a full-featured FTP client with an easy-to-use GUI</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>https://screenshots.debian.net/screenshots/000/015/296/large.png</screenshot>

<preinstall>

</preinstall>

<install_package_names>
filezilla
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
filezilla
</uninstall_package_names>
</app>

==> mx-packageinstaller-pkglist_19.09.03.tar.xz: mx-packageinstaller-pkglist/filezilla.pm <==
<?xml version="1.0"?>
<app>

<category>
FTP
</category>

<name>
Filezilla
</name>

<description>
   <am>a full-featured FTP client with an easy-to-use GUI</am>
   <ar>a full-featured FTP client with an easy-to-use GUI</ar>
   <bg>a full-featured FTP client with an easy-to-use GUI</bg>
   <ca>un client de FTP complet amb IGU fàcil d'usar</ca>
   <cs>a full-featured FTP client with an easy-to-use GUI</cs>
   <da>en FTP-klient med det hele med en brugerflade som er let at bruge</da>
   <de>Ein voll ausgestatter FTP-Client mit benutzerfreundliche Oberfläche</de>
   <el>ένα πλήρως εξοπλισμένο πρόγραμμα-πελάτη FTP με ένα εύχρηστο GUI</el>
   <en>a full-featured FTP client with an easy-to-use GUI</en>
   <es>Un cliente FTP con una interfaz completa y fácil de usar</es>
   <et>a full-featured FTP client with an easy-to-use GUI</et>
   <eu>a full-featured FTP client with an easy-to-use GUI</eu>
   <fa>a full-featured FTP client with an easy-to-use GUI</fa>
   <fi>a full-featured FTP client with an easy-to-use GUI</fi>
   <fr>Un client FTP très complet avec une interface graphique intuitive</fr>
   <he_IL>a full-featured FTP client with an easy-to-use GUI</he_IL>
   <hi>a full-featured FTP client with an easy-to-use GUI</hi>
   <hr>a full-featured FTP client with an easy-to-use GUI</hr>
   <hu>a full-featured FTP client with an easy-to-use GUI</hu>
   <id>a full-featured FTP client with an easy-to-use GUI</id>
   <is>a full-featured FTP client with an easy-to-use GUI</is>
   <it>Client Ftp ad interfaccia grafica, completo e di facile uso</it>
   <ja_JP>a full-featured FTP client with an easy-to-use GUI</ja_JP>
   <ja>a full-featured FTP client with an easy-to-use GUI</ja>
   <kk>a full-featured FTP client with an easy-to-use GUI</kk>
   <ko>a full-featured FTP client with an easy-to-use GUI</ko>
   <lt>a full-featured FTP client with an easy-to-use GUI</lt>
   <mk>a full-featured FTP client with an easy-to-use GUI</mk>
   <nb>a full-featured FTP client with an easy-to-use GUI</nb>
   <nl>een volledig voorzien FTP programma met een makkelijk te gebruiken grafische werkomgeving</nl>
   <pl>w pełni funkcjonalny klient FTP z łatwym w użyciu interfejsem graficznym</pl>
   <pt_BR>Cliente FTP completo com interface gráfica intuitiva</pt_BR>
   <pt>Cliente FTP completo com interface gráfica intuitiva</pt>
   <ro>a full-featured FTP client with an easy-to-use GUI</ro>
   <ru>Полнофункциональный FTP клиент с удобным GUI</ru>
   <sk>a full-featured FTP client with an easy-to-use GUI</sk>
   <sl>Polnozmogljiv FTP odjemalec z enostavnim uporabniškim vmesnikom</sl>
   <sq>a full-featured FTP client with an easy-to-use GUI</sq>
   <sr>a full-featured FTP client with an easy-to-use GUI</sr>
   <sv>en fullutrustad FTP klient med lättanvänt grafiskt gränssnitt</sv>
   <tr>a full-featured FTP client with an easy-to-use GUI</tr>
   <uk>повнофункціональний FTP-клієнт з простим у використанні графічним інтерфейсом</uk>
   <zh_CN>a full-featured FTP client with an easy-to-use GUI</zh_CN>
   <zh_TW>a full-featured FTP client with an easy-to-use GUI</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>https://screenshots.debian.net/screenshots/000/015/296/large.png</screenshot>

<preinstall>

</preinstall>

<install_package_names>
filezilla
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
filezilla
</uninstall_package_names>
</app>
